# File: app/celery_app.py

import os
import json
from celery import Celery

# ─── 1) Create & configure Celery ─────────────────────────────────────────────
celery = Celery('natureinpots')
# pull CELERY_BROKER_URL and CELERY_RESULT_BACKEND from your Config
celery.config_from_object('app.config.Config', namespace='CELERY')

# ─── 2) Ensure all tasks run inside a Flask app context ────────────────────────
TaskBase = celery.Task
class ContextTask(TaskBase):
    def __call__(self, *args, **kwargs):
        # lazy import to avoid circular import at module load time
        from app import create_app
        app = create_app()
        with app.app_context():
            return TaskBase.__call__(self, *args, **kwargs)

celery.Task = ContextTask

# ─── 3) Autodiscover all plugin tasks via plugin.json “tasks” entries ─────────
project_root = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
plugins_dir  = os.path.join(project_root, 'plugins')

task_modules = []
for plugin_name in sorted(os.listdir(plugins_dir)):
    manifest = os.path.join(plugins_dir, plugin_name, 'plugin.json')
    if not os.path.isfile(manifest):
        continue

    try:
        meta = json.load(open(manifest))
    except Exception:
        continue

    tasks_cfg = meta.get('tasks')
    if isinstance(tasks_cfg, str):
        task_modules.append(tasks_cfg)
    elif isinstance(tasks_cfg, dict) and tasks_cfg.get('module'):
        task_modules.append(tasks_cfg['module'])
    elif isinstance(tasks_cfg, list):
        for entry in tasks_cfg:
            if isinstance(entry, str):
                task_modules.append(entry)
            elif isinstance(entry, dict) and entry.get('module'):
                task_modules.append(entry['module'])

if task_modules:
    celery.autodiscover_tasks(task_modules)
