#!/usr/bin/env bash
set -euo pipefail

# ── 1) Wait for DB ─────────────────────────────────────────────────────────
DB_HOST="${DB_HOST:-${MYSQL_HOST:-db}}"
DB_PORT="${DB_PORT:-${MYSQL_PORT:-3306}}"
echo "[⏳] Waiting for database at $DB_HOST:$DB_PORT..."
until nc -z "$DB_HOST" "$DB_PORT"; do sleep 1; done
echo "[✔] Database is up"

# ── 2) Ensure uploads dir exists (no chown here—already owned at build) ────
UPLOAD_DIR="/app/${UPLOAD_FOLDER:-data/uploads}"
mkdir -p "$UPLOAD_DIR"
echo "⏺️  Ensured upload directory exists: $UPLOAD_DIR"

# ── 3) If we're running Flask, migrate & seed ─────────────────────────────
if [ "$1" = "flask" ]; then
  echo "[🛠️] Applying migrations"
  flask db upgrade

  echo "[🛠️] Creating any missing tables"
  python - <<EOF
from app import create_app, db
app = create_app()
with app.app_context():
    db.create_all()
EOF

  if [[ "${ENABLE_DB_SEEDING,,}" == "true" || "${ENABLE_DB_SEEDING}" == "1" ]]; then
    echo "[🌱] Seeding data"
    flask preload-data
  fi

  echo "[🚀] Starting Flask…"
fi

# ── 4) Exec the requested command (flask, celery, flower…) ───────────────
exec "$@"
