# File: migrations/env.py

import os
import sys
import json
import importlib

from logging.config import fileConfig
from sqlalchemy import engine_from_config
from sqlalchemy import pool

from alembic import context

# ─── Adjust path so we can import app and plugins ─────────────────────────────
project_root = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
sys.path.insert(0, project_root)

# ─── this is the Alembic Config object, which provides
# ─── access to the values within the .ini file in use.
config = context.config

# ─── Interpret the config file for Python logging.
# ─── This line sets up loggers basically.
fileConfig(config.config_file_name)

# ─── Import your app’s MetaData object for 'autogenerate' support ─────────────
# (assuming your app exposes it at app.db.metadata)
from app import db
target_metadata = db.metadata

# ─── Dynamically import all models listed in plugin.json manifests ────────────
plugins_dir = os.path.join(project_root, 'plugins')

for plugin in sorted(os.listdir(plugins_dir)):
    mfest = os.path.join(plugins_dir, plugin, 'plugin.json')
    if not os.path.isfile(mfest):
        continue
    try:
        meta = json.load(open(mfest))
    except Exception:
        continue

    # top-level models
    for model_mod in meta.get('models', []):
        try:
            importlib.import_module(model_mod)
        except ImportError:
            pass

    # nested subplugin models
    for sp in meta.get('subplugins', []):
        for model_mod in sp.get('models', []):
            try:
                importlib.import_module(model_mod)
            except ImportError:
                pass

# ─── target_metadata is now populated with all plugin tables ──────────────────

def run_migrations_offline():
    """Run migrations in 'offline' mode."""
    url = config.get_main_option("sqlalchemy.url")
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online():
    """Run migrations in 'online' mode."""
    connectable = engine_from_config(
        config.get_section(config.config_ini_section),
        prefix='sqlalchemy.',
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        context.configure(
            connection=connection,
            target_metadata=target_metadata,
            compare_type=True,
            compare_server_default=True,
        )

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()
