# plugins/utility/celery.py
from celery import Celery

# 1) Create Celery instance at import time so tasks can import celery_app
celery_app = Celery(__name__)

def init_celery(app):
    """
    Configure the global celery_app with Flask settings and
    ensure tasks run inside the Flask application context.
    """
    # Pull broker/backend from Flask config
    celery_app.conf.broker_url = app.config['CELERY_BROKER_URL']
    celery_app.conf.result_backend = app.config.get(
        'CELERY_RESULT_BACKEND',
        app.config['CELERY_BROKER_URL']
    )
    celery_app.conf.update(app.config)

    # Wrap all tasks in Flask app context
    TaskBase = celery_app.Task
    class ContextTask(TaskBase):
        def __call__(self, *args, **kwargs):
            with app.app_context():
                return super().__call__(*args, **kwargs)
    celery_app.Task = ContextTask

    return celery_app
